@@ -5,10 +5,9 @@
     ##.Call( "check_libprotobuf_version", minversion, PACKAGE = "RProtoBuf" )
     readProtoFiles( package=pkgname, lib.loc=libname )
     attachDescriptorPool( pos = length(search()) )
-
-    if( exists( ".httpd.handlers.env", asNamespace( "tools" ) ) ){
-        e <- tools:::.httpd.handlers.env
-        e[["RProtoBuf"]] <- RProtoBuf.http.handler
-    }
+    options("RProtoBuf.int64AsString" = FALSE)
+    #if( exists( ".httpd.handlers.env", asNamespace( "tools" ) ) ){
+    #    e <- tools:::.httpd.handlers.env
+    #    e[["RProtoBuf"]] <- RProtoBuf.http.handler
+    #}
 }
-
